"use strict";

exports.__esModule = true;
exports.default = useResponderEvents;

var React = _interopRequireWildcard(require("react"));

var ResponderSystem = _interopRequireWildcard(require("./ResponderSystem"));

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

/**
 * Copyright (c) Nicolas Gallagher
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * 
 */

/**
 * Hook for integrating the Responder System into React
 *
 *   function SomeComponent({ onStartShouldSetResponder }) {
 *     const ref = useRef(null);
 *     useResponderEvents(ref, { onStartShouldSetResponder });
 *     return <div ref={ref} />
 *   }
 */
var emptyObject = {};
var idCounter = 0;

function useStable(getInitialValue) {
  var ref = React.useRef(null);

  if (ref.current == null) {
    ref.current = getInitialValue();
  }

  return ref.current;
}

function useResponderEvents(hostRef, callbacks) {
  if (callbacks === void 0) {
    callbacks = emptyObject;
  }

  var id = useStable(function () {
    return idCounter++;
  });
  var isPotentialResponder = React.useRef(false); // On initial mount, attach global listeners if needed.
  // On unmount, remove node from the Responder System.
  // This is a separate effect so it doesn't run when `callbacks` changes.

  React.useEffect(function () {
    ResponderSystem.attachListeners();
    return function () {
      if (isPotentialResponder.current) {
        ResponderSystem.removeNode(id);
      }
    };
  }, [id]); // Register and unregister with the Responder System as necessary

  React.useEffect(function () {
    var _callbacks = callbacks,
        onMoveShouldSetResponder = _callbacks.onMoveShouldSetResponder,
        onMoveShouldSetResponderCapture = _callbacks.onMoveShouldSetResponderCapture,
        onScrollShouldSetResponder = _callbacks.onScrollShouldSetResponder,
        onScrollShouldSetResponderCapture = _callbacks.onScrollShouldSetResponderCapture,
        onSelectionChangeShouldSetResponder = _callbacks.onSelectionChangeShouldSetResponder,
        onSelectionChangeShouldSetResponderCapture = _callbacks.onSelectionChangeShouldSetResponderCapture,
        onStartShouldSetResponder = _callbacks.onStartShouldSetResponder,
        onStartShouldSetResponderCapture = _callbacks.onStartShouldSetResponderCapture;
    var requiresResponderSystem = onMoveShouldSetResponder != null || onMoveShouldSetResponderCapture != null || onScrollShouldSetResponder != null || onScrollShouldSetResponderCapture != null || onSelectionChangeShouldSetResponder != null || onSelectionChangeShouldSetResponderCapture != null || onStartShouldSetResponder != null || onStartShouldSetResponderCapture != null;
    var node = hostRef.current;

    if (requiresResponderSystem) {
      isPotentialResponder.current = true;
      ResponderSystem.addNode(id, node, callbacks);
    } else if (isPotentialResponder.current) {
      ResponderSystem.removeNode(id);
      isPotentialResponder.current = false;
    }
  }, [callbacks, hostRef, id]);
}

module.exports = exports.default;