/**
 * Copyright (c) Nicolas Gallagher.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * 
 */
import AccessibilityUtil from '../../modules/AccessibilityUtil';
import createDOMProps from '../../modules/createDOMProps';
import React from 'react';

var createElement = function createElement(component, props) {
  // Use equivalent platform elements where possible.
  var accessibilityComponent;

  if (component && component.constructor === String) {
    accessibilityComponent = AccessibilityUtil.propsToAccessibilityComponent(props);
  }

  var Component = accessibilityComponent || component;
  var domProps = createDOMProps(Component, props);
  var onClick = domProps.onClick,
      role = domProps.role;
  var isButtonLikeRole = AccessibilityUtil.buttonLikeRoles[role];
  var isDisabled = AccessibilityUtil.isDisabled(domProps); // Button-like roles should not trigger 'onClick' if they are disabled.

  if (isButtonLikeRole && isDisabled && domProps.onClick != null) {
    domProps.onClick = undefined;
  } // Button-like roles should trigger 'onClick' if SPACE or ENTER keys are pressed.


  if (isButtonLikeRole && !isDisabled) {
    domProps.onKeyDown = function (e) {
      if (!e.isDefaultPrevented() && (e.key === 'Enter' || e.key === ' ')) {
        e.preventDefault();

        if (onClick != null) {
          onClick(e);
        }
      }
    };
  }

  for (var _len = arguments.length, children = new Array(_len > 2 ? _len - 2 : 0), _key = 2; _key < _len; _key++) {
    children[_key - 2] = arguments[_key];
  }

  return React.createElement.apply(React, [Component, domProps].concat(children));
};

export default createElement;